function obj = cnt_connect(cnt)
%CNT_CONNECT Verbindung zum Frequenzzhler aufbauen
%   Kommunikation erfolgt mit SCPI-Befehlen
%   input arguments
%       cnt             Bezeichnung des zu verwendenden Frequenzzhlers
%                       untersttzt werden
%                       'none'      fr Testzwecke, Messwerte werden aus Datei gelesen
%                       '53230a'    National Instruments GPIB board, board index 0, 
%                                   Keysight 53230A, primary address 3
%   output arguments
%       obj             Instrument Object
%
%   Instrument Control Toolbox 
%       S. 1-23 bis 1-24
%
%   SCPI-Befehle 
%       *IDN?
%
%   28.11.2021          T. Weber    

switch cnt
    case 'none'
        % Dummy Object erzeugen
        obj.Name = 'none';
 
        disp('no frequency counter');
        
    case '53230a'
        % Verbindung herstellen, groen Eingangspuffer konfigurieren
        obj = gpib('ni',0,3,'InputBufferSize',2^25,'Timeout',1000,'Name',cnt);
        fopen(obj);

        % Abfrage der Instrument Identification zum Prfen der Verbindung
        fprintf(obj,'*IDN?');
        disp(fscanf(obj));
        
    otherwise
    	error('unsupported frequency counter');
        
end

end
