function [frequency,time,k] = cnt_frequency(obj,k,file)
%CNT_FREQUENCY Frequenzmessungen durchfhren
%   Kommunikation erfolgt mit SCPI-Befehlen
%   input arguments
%       obj             Instrument Object
%       k               Anzahl der Messungen
%       file            Dateiname
%   output arguments
%       frequency       gemessene Frequenzen
%       time            Messzeiten
%       k               tatschliche Anzahl der Messungen
%
%   Instrument Control Toolbox 
%       S. 1-23 bis 1-24
%       S. 3-19 bis 3-24
%
%   SCPI-Befehle 
%       SAMPle:COUNt {<count> | MINimum | MAXimum | DEFault}
%       READ?
%       [SENSe:]FREQuency:GATE:TIME? [{MINimum | MAXimum | DEFault}]
%
%   28.11.2021          T. Weber    
%   13.04.2023          Zeitachse hinzugefgt

switch obj.Name
    case 'none'
        % Messwerte aus Datei lesen
        data = load(file,'-ascii');
        time = data(:,1);
        frequency = data(:,2);
        k = numel(frequency);
        
    case '53230a'       
        % Anzahl der Messungen einstellen
        fprintf(obj,'SAMP:COUN %f',k);
        
        % Messungen durchfhren
        fprintf(obj,'READ?');
        frequency = scanstr(obj,',','%f');

        % Zeitachse
        fprintf(obj,'FREQ:GATE:TIME?');
        tau = fscanf(obj,'%f');
        time = (0:k-1)'*tau; 

        % Messwerte in Datei schreiben
        data = [time,frequency];
        save(file,'data','-ascii','-double');

    otherwise
    	error('unsupported frequency counter');
        
end

end
